[PATCH v3] partitions: dos: Fix support of extended partition type 0x05

Victorien Vedrine victorien.vedrine at ophrys.net
Mon Dec 22 09:20:22 PST 2014


From: victorien <victorien.vedrine at ophrys.net>

Signed-off-by: Victorien Vedrine <victorien.vedrine at ophrys.net>
---
 common/partitions/dos.c | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)

diff --git a/common/partitions/dos.c b/common/partitions/dos.c
index 37addfd..f02c822 100644
--- a/common/partitions/dos.c
+++ b/common/partitions/dos.c
@@ -205,11 +205,11 @@ static void dos_partition(void *buf, struct block_device *blk,
 			pd->used_entries++;
 			/*
 			 * Partitions of type 0x05 and 0x0f (and some more)
 			 * contain extended partitions. Only check for type 0x0f
 			 * here as this is the easiest to parse and common
 			 * enough.
 			 */
-			if (pentry.dos_partition_type == 0x0f) {
+			if (pentry.dos_partition_type == 0x0f ||
+				pentry.dos_partition_type == 0x05) {
 				if (!extended_partition)
 					extended_partition = &pd->parts[n];
 				else
@@ -205,11 +205,11 @@ static void dos_partition(void *buf, struct block_device *blk,
 			/*
 			 * Partitions of type 0x05 and 0x0f (and some more)
-			 * contain extended partitions. Only check for type 0x0f
-			 * here as this is the easiest to parse and common
-			 * enough.
+			 * contain extended partitions. Only check for type
+			 * 0x05 and 0x0f.
 			 */
-- 
1.9.1




More information about the barebox mailing list